@@ -25,7 +25,7 @@
 #' @examples \dontrun{
 #' #  Search for sites with "Pseudotsuga" pollen that are older than 8kyr BP and
 #' #  that are roughly within western British Columbia:
-#' t8kyr.datasets <- get_dataset(taxonname='*Picea*', loc=c(-90, 41, -89, 44), 
+#' t8kyr.datasets <- get_dataset(taxonname='*Picea*', loc=c(-90, 41, -89, 44),
 #'                               ageold = 20000, ageyoung=10000)
 #'
 #' #  Returns 20 records (as of 04/04/2013), get the dataset for all records:
@@ -54,17 +54,17 @@
 #'
 #' smooth.curve <- predict(loess(sqrt(count)~age, data=curves),
 #'                         data.frame(age=seq(20000, 0, by = -100)))
-#'                         
+#'
 #' plot(sqrt(count) ~ age, data = curves,
 #'      ylab = '% Pseudotsuga/Larix', xlab='Calibrated Years BP', pch=19,
 #'      col=rgb(0.1, 0.1, 0.1, 0.1), xlim=c(0, 20000))
 #' lines(seq(20000, 0, by = -100), smooth.curve, lwd=2, lty=2, col=2)
 #'
-#' #  This figure shows us an apparent peak in Larix/Pseudotsuga pollen in the 
+#' #  This figure shows us an apparent peak in Larix/Pseudotsuga pollen in the
 #' #  early-Holocene that lends support to a warmer, drier early-Holocene in
 #' #  western North America.
 #' }
-#' 
+#'
 #' @references
 #' Neotoma Project Website: http://www.neotomadb.org
 #' API Reference:  http://api.neotomadb.org/doc/resources/contacts
@@ -98,11 +98,11 @@ get_download.default <- function(x, verbose = TRUE) {
   get.sample <- function(x) {
     # query Neotoma for data set
     base.uri <- 'http://api.neotomadb.org/v1/data/downloads'
-    
+
     neotoma_content <- httr::content(httr::GET(paste0(base.uri, '/', x)), as = "text")
     if (identical(neotoma_content, "")) stop("")
     aa <- jsonlite::fromJSON(neotoma_content, simplifyVector = FALSE)
-    
+
     # Might as well check here for error and bail
     if (inherits(aa, "try-error"))
         return(aa)
@@ -121,8 +121,8 @@ get_download.default <- function(x, verbose = TRUE) {
         return(NULL)
       }
         aa <- aa[[2]]
-        
-        rep_NULL <- function(x) { 
+
+        rep_NULL <- function(x) {
           # small function to recursively fill all NULL values with NAs.
           if (is.null(x)) {NA}
           else{
@@ -133,9 +133,9 @@ get_download.default <- function(x, verbose = TRUE) {
             }
           }
         }
-        
+
         aa <- lapply(aa, function(x)rep_NULL(x))
-        
+
         if (verbose) {
             message(strwrap(paste0("API call was successful. ",
                                    "Returned record for ",
@@ -181,21 +181,21 @@ get_download.default <- function(x, verbose = TRUE) {
             access.date = Sys.time())
 
           # Assign classes
-          
+
           class(dataset) <- c('dataset', 'list')
           class(dataset$site) <- c('site', 'data.frame')
-          
+
           #  Geochronological datasets behave differently than any other dataset.
           #  It's frustrating.  This is the only way we can figure it out in a
           #  general way.
           if (dataset$dataset.meta$dataset.type == 'geochronologic') {
-            
+
             message(paste0('The dataset ID ', dataset$dataset.meta$dataset.id,
                            ' is associated with a geochronology object, not count data.'))
             return(NULL)
 
           } else {
-            
+
             # copy to make indexing below easier?
             samples <- aa1$Samples
 
@@ -218,25 +218,25 @@ get_download.default <- function(x, verbose = TRUE) {
 
             # First, get all unique chronology names.
             # Some cores don't have age models, so we use a try function.
-            
+
             # There is an issue in about 31 records in the US database (where I tested)
             # where there are samples without named sample ages, but not a second chronology.
             # The issue is that there are undated samples within a record that has dated records.
             # So some samples are NAPD1 and then the undated samples, deeper in the core are just 'NA'
             # This means that NA is just a continuous flow from NAPD1.
-            
+
             # In records with two chronologies we get an array with two rows.
             # If there are unidentified samples within the chronology they aren't named.
             # This becomes problematic when we have `n` chronologies, plus samples without
             # named chronologies.
-            
+
             chron_list <- lapply(samples, '[[', 'SampleAges')
-            
+
             chron_names <- unique(unlist(sapply(chron_list, function(x)unique(sapply(x, '[[', 'ChronologyName')))))
             chron_lengths <- sapply(chron_list, length)
             # When there is an NA aged sample in a record it makes everything worse
             # because it's not inherently a part of a chronology.
-            
+
             if (any(is.na(chron_names)) & !all(diff(chron_lengths) == 0)) {
               # This implies that many records have multiple chronology
               # coverage, but that some don't & have NA coverage.
@@ -247,7 +247,7 @@ get_download.default <- function(x, verbose = TRUE) {
                   return(x)
                 } else {
                   x <- rep(x, max(chron_lengths))
-                  return(lapply(1:max(chron_lengths), 
+                  return(lapply(1:max(chron_lengths),
                           function(y) {x[[y]]$ChronologyName <- chron_names[y]; x[[y]]}))
                 }
               }
@@ -264,20 +264,20 @@ get_download.default <- function(x, verbose = TRUE) {
                     return(x)
                   } else {
                     x <- rep(x, max(chron_lengths))
-                    return(lapply(1:max(chron_lengths), 
+                    return(lapply(1:max(chron_lengths),
                                   function(y) {x[[y]]$ChronologyName <- chron_names[y]; x[[y]]}))
                   }
                 }
-                chron_list <- lapply(chron_list, reassign, chron_names = chron_names)   
+                chron_list <- lapply(chron_list, reassign, chron_names = chron_names)
             }
-            
+
             chron_vectors <- sapply(chron_list, function(x)unique(sapply(x, '[[', 'ChronologyName')))
 
             if (is.list(chron_vectors)) {
               #  If it's a list then there are levels without common chronologies
               #  in practice this is more likely for faunal/macrofossil remains.
               unique_vectors <- stats::na.omit(unique(unlist(chron_vectors)))
-              
+
               # Now, we inject an empty age for the missing chronology:
               for (i in unique_vectors) {
                 for (j in 1:length(chron_list)) {
@@ -287,31 +287,31 @@ get_download.default <- function(x, verbose = TRUE) {
                       chron_list[[j]][[which(is.na(sapply(chron_list[[j]], '[[', 'ChronologyName')))]] <- NULL
                     }
                     add_length <- length(chron_list[[j]]) + 1
-                    
+
                     chron_list[[j]][[add_length]] <- list(AgeOlder = NA,
                                                           Age = NA,
                                                           AgeYounger = NA,
                                                           ChronologyName = i,
                                                           AgeType = NA,
                                                           ChronologyID = NA)
-                    
+
                   }
                 }
               }
-              
+
               # Now we just need to re-sort the lists:
               chron_list <- lapply(chron_list, function(x){
                 lapply(match(sapply(x, '[[', 'ChronologyName'), unique_vectors), function(y)x[[y]])
               })
-              
+
               chron_vectors <- sapply(chron_list, function(x)unique(sapply(x, '[[', 'ChronologyName')))
-              
+
             }
             # This fills in the end of a set of sample ages if there are NAs in a series,
             # but with the fix above it shouldn't be necessary.
             if (!is.null(nrow(chron_vectors))) {
               # There's a problem here that the things aren't in the right order.
-              
+
               chron_vectors <- t(apply(chron_vectors, 1, function(x) {
                                         if (any(is.na(x)) & !all(is.na(x))) {
                                           x[is.na(x)] <- unique(x[!is.na(x)])
@@ -320,17 +320,17 @@ get_download.default <- function(x, verbose = TRUE) {
             } else {
               chron_vectors[is.na(chron_vectors)] <- unique(unlist(chron_vectors[!is.na(chron_vectors)]))
             }
-            
+
             chrons <- try(unique(as.vector(unlist(chron_vectors))), silent = TRUE)
 
             base.frame <- data.frame(age.older = rep(NA, nrow(sample.meta)),
                                      age = rep(NA, nrow(sample.meta)),
                                      age.younger = rep(NA, nrow(sample.meta)),
                                      chronology.name = rep(NA, nrow(sample.meta)),
-                                     age.type = rep(NA, nrow(sample.meta)), 
-                                     chronology.id = rep(NA, nrow(sample.meta)), 
+                                     age.type = rep(NA, nrow(sample.meta)),
+                                     chronology.id = rep(NA, nrow(sample.meta)),
                                      dataset.id = rep(NA, nrow(sample.meta)))
-            
+
             colnames(base.frame) <- c('age.older', 'age',
                                       'age.younger', 'chronology.name',
                                       'age.type', 'chronology.id', 'dataset.id')
@@ -340,38 +340,38 @@ get_download.default <- function(x, verbose = TRUE) {
               # If they don't, then we stick in the empty `base.frame` and assign it a name "1"
               # Create the list:
               chron.list <- lapply(1:length(chrons), function(x) base.frame)
-              
+
               if (!(is.null(chrons) | any(is.na(chrons))) & length(chrons) > 0) {
                 # If there is a chronology and there are no NAs in it:
                 names(chron.list) <- chrons
 
                 for (i in 1:length(samples)) {
-                  
+
                   if (length(chron_list[[i]]) < length(chrons) & length(chron_list[[i]]) == 1) {
                     #  If there's a sample with nothing in it then it gets only a single
                     # chron_list object, which makes the `j` loop choke.
                     #  This current implementation only accounts for a completely
                     # undated sample within the core, but not if one model spans a different length
                     # of the core.
-                    
+
                     for (j in 1:length(chrons)) {
                       # Fix the `j` placeholder at 1
                       chron.list[[j]][i, ] <- data.frame(chron_list[[i]][[1]],
                                                          stringsAsFactors = FALSE)
                       chron.list[[j]]$dataset.id <- dataset$dataset.meta$dataset.id
                     }
-                    
+
                   } else if (!is.null(chrons) & any(is.na(chrons)) & length(chrons) > 0) {
                     # There is a chronology, but one of levels has an NA:
                     for (i in 1:length(chron_list)) {
                       chron_list
                     }
-                    
+
                   } else {
                     for (j in 1:length(chrons)) {
                       # Some of the new datasets are passing data without any chronology information.
                       # Here we're filling in the dataset metadata
-                      
+
                       chron.list[[j]][i, ] <- data.frame(chron_list[[i]][[j]],
                                                          stringsAsFactors = FALSE)
                       chron.list[[j]]$dataset.id <- dataset$dataset.meta$dataset.id
@@ -384,17 +384,17 @@ get_download.default <- function(x, verbose = TRUE) {
                              stringsAsFactors = FALSE)
                 chron.list[[1]]$dataset.id <- dataset$dataset.meta$dataset.id
               }
-              
+
               default_chron <- which(sapply(chron.list, function(x)x$chronology.id[1]) == aa1$DefChronologyID)
               if (length(default_chron) > 1) { default_chron <- default_chron[1] }
-              
+
               if (length(default_chron) == 0) {
                 warning(paste0('This dataset has no defined default chronology.  Please use caution.\n',
                         'Using the first chronology, ', names(chron.list)[1],' as the default.'),
                         immediate. = TRUE)
                 default_chron <- 1
               }
-              
+
             } else {
               chron.list <- list(base.frame)
               default_chron <- 1
@@ -407,7 +407,7 @@ get_download.default <- function(x, verbose = TRUE) {
 
             # stick all that together, setting names, & reordering cols
             # the most recent age model is provided as the default.
-            # 
+            #
             sample.meta <- cbind.data.frame(sample.meta,
                                             chron.list[[default_chron]],
                                             unlist(sample.names))
@@ -424,12 +424,12 @@ get_download.default <- function(x, verbose = TRUE) {
             # list of data frames
             sample.data <- lapply(lapply(samples, `[[`, "SampleData"),
                                   function(x) do.call(rbind.data.frame, x))
-            
+
             if (length(unlist(sample.data)) == 0) {
               warning('This record contains no count data.  Returning a NULL record.')
               return(NULL)
             }
-            
+
             if (any(sapply(sample.data, length) == 0)) {
               sample.data <- lapply(sample.data, function(x) {
                 if(length(x) == 0) {
@@ -437,58 +437,59 @@ get_download.default <- function(x, verbose = TRUE) {
                                   VariableUnits = NA,
                                   VariableElement = NA,
                                   VariableContext = NA,
-                                  TaxaGroup = NA, 
-                                  Value = NA, 
-                                  EcolGroupID = NA)
+                                  TaxaGroup = NA,
+                                  Value = NA,
+                                  EcolGroupID = NA,
+                                  stringsAsFactors = FALSE)
                 }
                 return(x)
               })
             }
-            
+
             # 2) How many counts/species in each data frame?
             nsamp <- sapply(sample.data, nrow)
-            
+
             # 3) bind each data frame - result is a data frame in long format
             sample.data <- do.call(rbind, sample.data)
-            
+
             # 4) add a Sample column that is the ID from sample.meta
             sample.data$sample.id <- rep(sample.meta$sample.id, times = nsamp)
 
             # We're going to isolate the count data and clean it up by
             # excluding lab data and charcoal.  The charcoal exclusion
             # needs some further consideration.
-            
+
             colnames(sample.data) <- c('taxon.name', 'variable.units',
                                        'variable.element', 'variable.context',
                                        'taxon.group', 'value',
                                        'ecological.group', 'sample.id')
-            
+
             # get the table:
-            cast_table <- reshape2::dcast(sample.data, 
+            cast_table <- reshape2::dcast(sample.data,
                                 taxon.name + variable.units + variable.element +
                                   variable.context + taxon.group +
                                   ecological.group ~ sample.id, value.var = "value", fun.aggregate = sum)
-            
+
             cast_table <- cast_table[!is.na(cast_table$taxon.name), ]
             taxon.list <- cast_table[ ,1:6]
-            
+
             # Now we check for any duplicated names and give them an alias
             # that binds the name with the variable units.
             if (any(duplicated(cast_table$taxon.name))) {
-              
+
               which_dup <- as.character(taxon.list$taxon.name[duplicated(taxon.list$taxon.name)])
-              
+
               # A variable may be duplicated because the same variable was mapped in
               # different units, or because it comes from different contexts.
               # So we want to replace with the appropriate name:
-              
+
               taxon.list$alias <- as.character(taxon.list$taxon.name)
-              
+
               for (i in which_dup) {
                 # Choose the column to resolve the problem.
                 dup_rows <- data.frame(taxon.list[taxon.list$taxon.name %in% i,],
                                        stringsAsFactors = FALSE)
-                
+
                 # The pick order should be:
                 # 1. variable.context
                 # 2. variable.element - it's clear
@@ -496,14 +497,14 @@ get_download.default <- function(x, verbose = TRUE) {
                 # 4. context|element
                 dup_rows <- dup_rows[,c('variable.context','variable.element',
                                         'variable.units')]
-                
+
                 # Remove any columns where all elements are NA:
                 dup_rows <- dup_rows[, apply(dup_rows, 2, function(x) { !all(is.na(x)) } )]
-                
+
                 #  To resolve the duplication issue we want to find the shortest combination of columns for
                 #  which the sum of duplicates is zero:
                 if (is.null(nrow(dup_rows))) {
-                  # In some cases there are lots of NAs. . . 
+                  # In some cases there are lots of NAs. . .
                   taxon.list$alias[taxon.list$taxon.name %in% i] <-  paste0(taxon.list$alias[taxon.list$taxon.name %in% i], '|',
                                                                             as.character(dup_rows))
                 } else {
@@ -513,13 +514,13 @@ get_download.default <- function(x, verbose = TRUE) {
                                                                                              paste0(as.character(t(dup_rows)[,x]), collapse = '|')) })
                 }
               }
-              
+
               message <- paste0('\nThere were multiple entries for ',
                                 unique(which_dup),
                                 sapply(unique(which_dup), function(x)ifelse(length(grep("\\.$", 'abcd', perl = TRUE)) == 1, '.', '')),
                                 ' \nget_download has mapped aliases for the taxa in the taxon.list.')
               warning(immediate. = TRUE, message, call. = FALSE)
-            }  
+            }
 
             # This pulls out charcoal & lab data to stick in a different data.frame.
             take <- !(taxon.list$taxon.group == "Laboratory analyses" |
@@ -534,7 +535,7 @@ get_download.default <- function(x, verbose = TRUE) {
 
             # Pull out the lab data and treat it in
             # the same way as the previous:
-            
+
             if (sum(take) > 0) {
               lab.data <- t(cast_table[!take, 7:ncol(cast_table)])
               colnames(lab.data) <- taxon.list$alias[!take]
@@ -549,7 +550,7 @@ get_download.default <- function(x, verbose = TRUE) {
                        counts = count.data,
                        lab.data = lab.data,
                        chronologies = chron.list)
-          
+
             class(aa) <- c('download', 'list')
           }
         }
@@ -557,11 +558,11 @@ get_download.default <- function(x, verbose = TRUE) {
           message('Dataset contains no sample data.')
           return(NULL)
         }
-    
+
     }
-    
+
     aa
-    
+
   }
 
   aa <- lapply(x, get.sample)
@@ -576,13 +577,13 @@ get_download.default <- function(x, verbose = TRUE) {
       aa <- aa[-(which(sapply(aa,is.null), arr.ind = TRUE))]
     }
   }
-  
+
   names(aa) <- sapply(lapply(lapply(aa, '[[', 'dataset'), '[[', 'dataset.meta'), '[[', 'dataset.id')
-  
+
   class(aa) <- c('download_list', 'list')
 
   aa
-  
+
 }
 
 #' @title Function to return full download records using a \code{dataset}.
@@ -596,9 +597,9 @@ get_download.dataset <- function(x, verbose = TRUE) {
   # Updated the processing here. There is no need to be fiddling with
   # call. Use missing() to check for presence of argument
   # and then process as per usual
-  
+
   datasetid <- x$dataset.meta$dataset.id
-  
+
   if (!x$dataset.meta$dataset.type %in% 'geochronologic') {
     aa <- get_download(datasetid, verbose = verbose)
   } else {
@@ -618,15 +619,15 @@ get_download.dataset <- function(x, verbose = TRUE) {
 #' @param verbose logical; should messages on API call be printed?
 #' @export
 get_download.dataset_list <- function(x, verbose = TRUE) {
-  
+
   # Updated the processing here. There is no need to be fiddling with
   # call. Use missing() to check for presence of argument
   # and then process as per usual
-  
+
   datasetid <- sapply(x, FUN = function(x)x$dataset$dataset.id)
-  
+
   aa <- get_download(datasetid, verbose = verbose)
-  
+
   aa
 }
 
@@ -637,14 +638,14 @@ get_download.dataset_list <- function(x, verbose = TRUE) {
 #' @param verbose logical; should messages on API call be printed?
 #' @export
 get_download.site <- function(x, verbose = TRUE) {
-  
+
   message('Fetching datasets for the site(s)')
   dataset <- get_dataset(x)
-  
+
   datasetid <- unlist(lapply(dataset, FUN = function(x)x$dataset$dataset.id))
-  
+
   message('Getting downloads:')
   aa <- get_download(datasetid, verbose = verbose)
-  
+
   aa
 }
