@@ -94,13 +94,14 @@ param_check <- function(cl) {
   # Parameter check for the datasettype, make sure
   # it's one of the accepted types:
   if ('datasettype' %in% names(cl)) {
-    settypes <- c('geochronologic', 'loss-on-ignition', 'pollen', 'plant macrofossil', 
-                  'vertebrate fauna', 'macroinvertebrate', 'pollen surface sample', 'insect', 
-                  'ostracode', 'water chemistry', 'diatom', 'ostracode surface sample', 
-                  'diatom surface sample', 'geochemistry', 'physical sedimentology', 
-                  'charcoal', 'testate amoebae', 'X-ray fluorescence (XRF)', 'X-ray diffraction (XRD)', 
-                  'energy dispersive X-ray spectroscopy (EDS/EDX)', 'biomarker', 
-                  'modern plant biomarker', 'phytolith', 'stable isotope', 'paleomagnetic')
+    settypes <- c('geochronologic', 'loss-on-ignition', 'pollen', 'plant macrofossil', 'vertebrate fauna', 
+                  'macroinvertebrate', 'pollen surface sample', 'insect', 'ostracode', 'water chemistry', 
+                  'diatom', 'ostracode surface sample', 'diatom surface sample', 'geochemistry', 
+                  'physical sedimentology', 'charcoal', 'testate amoebae', 'X-ray fluorescence (XRF)', 
+                  'X-ray diffraction (XRD)', 'energy dispersive X-ray spectroscopy (EDS/EDX)', 'biomarker', 
+                  'modern plant biomarker', 'phytolith', 'specimen stable isotope', 'paleomagnetic', 
+                  'biochemistry', 'modern biochemistry', 'organic carbon', 'insect modern', 'chironomid', 
+                  'stable isotope', 'testate amoebae surface sample', 'charcoal surface sample', 'cladocera')
     
     set <- pmatch(cl$datasettype, settypes, nomatch = NA)
     if (is.na(set)) {
